pub enum DecodeError {
BufferTooShort {
expected: usize,
actual: usize,
},
InvalidUtf8,
InvalidUtf16,
FieldOutOfBounds {
field: &'static str,
offset: usize,
size: usize,
buf_len: usize,
},
UnsupportedDecoder(&'static str),
}Expand description
Errors that can occur during artifact decoding.
Variants
BufferTooShort
The raw data buffer is too short for the decoder to operate.
InvalidUtf8
The raw data is not valid UTF-8 where UTF-8 was expected.
InvalidUtf16
The raw data is not valid UTF-16LE.
FieldOutOfBounds
A binary field offset+size exceeds the buffer length.
UnsupportedDecoder(&'static str)
The decoder variant does not apply to this data shape.